@@ -8,7 +8,7 @@ def get_keywords(file_path, max_ngram_size=3, deduplication_threshold=0.9, numOf
     # open the pdf file in binary mode
     with open(file_path, 'rb') as pdf_file:
         # create a PDF reader object
-        pdf_reader = PyPDF2.PdfFileReader(pdf_file)
+        pdf_reader = PyPDF2.PdfReader(pdf_file)
         # get the number of pages
         num_pages = pdf_reader.numPages
         # initialize the text variable
